==> sage-v0.3-2005-06-03-src.tar: sage-0.3/sage/rings/__integer_test.py <==
from sage.all import *
from integer import *
def foo0():	"""
The integers.
"""

def foo1():	"""
        Return a copy of the integer.
        """

def foo2():	"""
        Coerces n to a C signed integer if possible, and sets self
        equal to n.
        """

def foo3():	"""
        Set self equal to the number defined by the s in the given
        base.
        """

def foo4():	"""
        EXAMPLES:
            >>> a = Integer(5); b = Integer(3)
            >>> b - a
            -2
        """

def foo5():	"""
        """

def foo6():	"""
        powermod(self, Integer exp, Integer mod):
        Compute self**exp modulo mod.
        """

def foo7():	"""
        Return the prime factorization of self as a list of
        pairs (p,e).
        """

def foo8():	"""
        Returns the least common multiple of self and n.
        """

def foo9():	"""
        Returns True if this integer is not divisible by the square of
        any prime and False otherwise.
        EXAMPLES:

        """

def foo10():	"""
        Return IntegerRing().
        """

def foo11():	"""
        Returns the integer floor of the square root of self.
        EXAMPLE:
            >>> a = Integer(5)
            >>> a.sqrt()
            2
        """

def foo12():	"""
        Return a triple g, s, t of Integers such that
               g = s * self + t * n.
        """

def foo13():	"""
        """

def foo14():	"""
        """

def foo15():	"""
        """

def foo16():	"""
        Returns the inverse of self modulo n, if this inverse exists.
        Otherwise, raises a ZeroDivisionError exception.
        
        INPUT:
           self -- Integer
           n -- Integer
        OUTPUT:
           x -- Integer such that x*self = 1 (mod m), or
                raises ZeroDivisionError.
        IMPLEMENTATION:
           Call the mpz_invert GMP library function.
        EXAMPLES:
        >>> a = Integer(189)
        >>> a.inverse_mod(10000)
        4709
        >>> a.inverse_mod(-10000)
        4709
        >>> a.inverse_mod(1890)
        Traceback (most recent call last):
        ...
        ZeroDivisionError: Inverse of 189 mod 1890 does not exist.
        """

def foo17():	"""
        Return the greatest common divisor of self and n.
        """

def foo18():	"""
        Return unique integer between 0 and m*n that is self modulo m
        and y modulo n.  We assume that m and n are coprime.
        """

def foo19():	"""
    Return the factorial 1 *2 * 3 * ... * n.
    """


if __name__ ==  '__main__':
    import doctest, sys
    doctest.testmod(sys.modules[__name__])

==> sage-v0.3-2005-06-24-src.tar: sage-0.3/sage/rings/__integer_test.py <==
from sage.all import *
from integer import *
def foo0():	"""
The integers.
"""

def foo1():	"""
        Return a copy of the integer.
        """

def foo2():	"""
        Coerces n to a C signed integer if possible, and sets self
        equal to n.
        """

def foo3():	"""
        Set self equal to the number defined by the s in the given
        base.
        """

def foo4():	"""
        EXAMPLES:
            >>> a = Integer(5); b = Integer(3)
            >>> b - a
            -2
        """

def foo5():	"""
        """

def foo6():	"""
        powermod(self, Integer exp, Integer mod):
        Compute self**exp modulo mod.
        """

def foo7():	"""
        Return the prime factorization of self as a list of
        pairs (p,e).
        """

def foo8():	"""
        Returns the least common multiple of self and n.
        """

def foo9():	"""
        Returns True if this integer is not divisible by the square of
        any prime and False otherwise.
        EXAMPLES:

        """

def foo10():	"""
        Return IntegerRing().
        """

def foo11():	"""
        Returns the integer floor of the square root of self, or raises
        an ValueError if self is negative. 
        EXAMPLE:
            >>> a = Integer(5)
            >>> a.isqrt()
            2
        """

def foo12():	"""
        Returns the square root of self if self is a perfect square,
        or raises a ValueError otherwise.
        EXAMPLE:
            >>> a = Integer(4)
            >>> a.sqrt()
            2
            >>> a = Integer(5)
            >>> a.sqrt()
            Traceback (most recent call last):
            ...
            ValueError: 5 is not a perfect square.
        """

def foo13():	"""
        Return a triple g, s, t of Integers such that
               g = s * self + t * n.
        """

def foo14():	"""
        """

def foo15():	"""
        """

def foo16():	"""
        """

def foo17():	"""
        Returns the inverse of self modulo n, if this inverse exists.
        Otherwise, raises a ZeroDivisionError exception.
        
        INPUT:
           self -- Integer
           n -- Integer
        OUTPUT:
           x -- Integer such that x*self = 1 (mod m), or
                raises ZeroDivisionError.
        IMPLEMENTATION:
           Call the mpz_invert GMP library function.
        EXAMPLES:
        >>> a = Integer(189)
        >>> a.inverse_mod(10000)
        4709
        >>> a.inverse_mod(-10000)
        4709
        >>> a.inverse_mod(1890)
        Traceback (most recent call last):
        ...
        ZeroDivisionError: Inverse of 189 mod 1890 does not exist.
        """

def foo18():	"""
        Return the greatest common divisor of self and n.
        """

def foo19():	"""
        Return unique integer between 0 and m*n that is self modulo m
        and y modulo n.  We assume that m and n are coprime.
        """

def foo20():	"""
    Return the factorial 1 *2 * 3 * ... * n.
    """


if __name__ ==  '__main__':
    import doctest, sys
    doctest.testmod(sys.modules[__name__])
